BEGIN
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'SUSER_ATTR_CHANGES_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM SUSER_ATTR_CHANGES_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'SUSER_ATTR_CHANGES_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW SUSER_ATTR_CHANGES_V';
  END LOOP;
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'SUSER_ALL_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM SUSER_ALL_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'SUSER_ALL_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW SUSER_ALL_V';
  END LOOP;
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'SUSER_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM SUSER_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'SUSER_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW SUSER_V';
  END LOOP;
END;
/

CREATE VIEW suser_v AS
  SELECT
    suser.id,
    suser.deleted,
    suser.department,
    suser.display_description,
    suser.display_name,
    suser.dn,
    suser.effective,
    suser.employee_status,
    suser.employee_type,
    TO_CHAR(suser.first_name) first_name,
    suser.full_name,
    suser.guid,
    suser.home_phone,
    suser.idm_dn,
    suser.idm_tree_name,
    suser.is_curated,
    suser.job_code,
    TO_CHAR(suser.job_title) job_title,
    TO_CHAR(suser.last_name) last_name,
    suser.location,
    suser.merged,
    TO_CHAR(suser.middle_name) middle_name,
    suser.office_phone,
    suser.other_phone,
    suser.preferred_locale,
    suser.provisioning_id,
    suser.secondary_supervisor_id,
    suser.supervisor_attr_key,
    suser.supervisor_id,
    suser.supervisor_unique_id,
    TO_CHAR(suser.unique_user_id) unique_user_id,
    TO_CHAR(suser.user_id) user_id,
    suser.business_unit,
    suser.collected_entity,
    suser.effective_entity,
    suser.identity_source,
    suser.sversion,
    TO_CHAR(suser.workforce_id) workforce_id,
    suser_email.email,
    suser.risk
  FROM suser
    LEFT JOIN (SELECT
        suser.id suser,
        suser.display_name,
        LISTAGG(TO_CHAR(suser_email.email), ' | ') WITHIN GROUP(ORDER BY email) email
      FROM suser
        JOIN suser_email ON suser.id = suser_email.suser
      WHERE suser.effective = 1 AND suser.deleted = 0  
      GROUP BY suser.id, suser.display_name) suser_email ON suser.id = suser_email.suser
  WHERE suser.deleted = 0 AND suser.effective = 1;

CREATE VIEW suser_all_v AS
  SELECT
    suser.id,
    suser.deleted,
    suser.department,
    suser.display_description,
    suser.display_name,
    suser.dn,
    suser.effective,
    suser.employee_status,
    suser.employee_type,
    TO_CHAR(suser.first_name) first_name,
    suser.full_name,
    suser.guid,
    suser.home_phone,
    suser.idm_dn,
    suser.idm_tree_name,
    suser.is_curated,
    suser.job_code,
    TO_CHAR(suser.job_title) job_title,
    TO_CHAR(suser.last_name) last_name,
    suser.location,
    suser.merged,
    TO_CHAR(suser.middle_name) middle_name,
    suser.office_phone,
    suser.other_phone,
    suser.preferred_locale,
    suser.provisioning_id,
    suser.secondary_supervisor_id,
    suser.supervisor_attr_key,
    suser.supervisor_id,
    suser.supervisor_unique_id,
    TO_CHAR(suser.unique_user_id) unique_user_id,
    TO_CHAR(suser.user_id) user_id,
    suser.business_unit,
    suser.collected_entity,
    suser.effective_entity,
    suser.identity_source,
    suser.sversion,
    TO_CHAR(suser.workforce_id) workforce_id,
    suser_email.email,
    suser.risk
  FROM suser
    LEFT JOIN (SELECT
        suser.id suser,
        suser.display_name,
        LISTAGG(TO_CHAR(suser_email.email), ' | ') WITHIN GROUP(ORDER BY email) email
      FROM suser
        JOIN suser_email ON suser.id = suser_email.suser
      WHERE suser.effective = 1 AND suser.deleted = 0  
      GROUP BY suser.id, suser.display_name) suser_email ON suser.id = suser_email.suser;

CREATE VIEW suser_attr_changes_v AS
  SELECT 
    TO_CHAR(su.first_name) first_name,
    TO_CHAR(su.middle_name) middle_name,
    TO_CHAR(su.last_name) last_name,
    su.office_phone,
    min(sv.timestamp) AS timestamp,
    su.home_phone,
    su.other_phone,
    su.department,
    TO_CHAR(su.job_title) job_title,
    semail.email,
    su.display_description,
    su.employee_status,
    su.employee_type,
    su.location,
    su.preferred_locale,
    su.supervisor_unique_id,
    supervisor.display_name as supervisor_display_name,
    TO_CHAR(supervisor.workforce_id) as supervisor_workforce_id,
    TO_CHAR(su.workforce_id) workforce_id,
    su.risk,
    min(su.sversion) AS sversion,
    TO_CHAR(su.unique_user_id) unique_user_id
  FROM suser su
    LEFT JOIN suser supervisor ON supervisor.workforce_id = su.supervisor_id
      JOIN sversion sv ON su.sversion = sv.id AND su.deleted = 0 AND su.collected_entity = su.effective_entity
      LEFT JOIN ( SELECT 
          su2.id AS suser_id,
          listagg(TO_CHAR(semail2.email), ' | ') WITHIN GROUP (ORDER BY semail2.email) AS email
        FROM suser su2
          JOIN suser_email semail2 ON su2.id = semail2.suser AND su2.is_curated = 0 AND su2.deleted = 0
        GROUP BY su2.id) semail ON semail.suser_id = su.id
  GROUP BY su.first_name, su.middle_name, su.last_name, su.office_phone, su.home_phone, su.other_phone, su.department, su.job_title, semail.email, su.display_description, su.employee_status, su.employee_type, su.location, su.preferred_locale, su.supervisor_unique_id, supervisor.display_name, supervisor.workforce_id, su.workforce_id, su.risk, su.unique_user_id;

GRANT SELECT ON igops.suser_v TO ig_report_role;
CREATE PUBLIC SYNONYM suser_v FOR igops.suser_v;

GRANT SELECT ON igops.suser_all_v TO ig_report_role;
CREATE PUBLIC SYNONYM suser_all_v FOR igops.suser_all_v;

GRANT SELECT ON igops.suser_attr_changes_v TO ig_report_role;
CREATE PUBLIC SYNONYM suser_attr_changes_v FOR igops.suser_attr_changes_v;